@@ -7,9 +7,12 @@
 #include "dfontinfomanager.h"
 #include "dfinstallnormalwindow.h"
 #include "utils.h"
+#include <QDebug>
 
 #include <DApplication>
+#if QT_VERSION_MAJOR <= 5
 #include <DApplicationHelper>
+#endif
 #include <DVerticalLine>
 
 #include <QButtonGroup>
@@ -36,6 +39,8 @@ DFInstallErrorDialog::DFInstallErrorDialog(QWidget *parent, const QStringList &e
     , m_signalManager(SignalManager::instance())
     , m_errorInstallFiles(errorInstallFontFileList)
 {
+    qDebug() << "DFInstallErrorDialog created with" << errorInstallFontFileList.size()
+             << "error font files";
 //    setWindowOpacity(0.3); //Debug
     initData();
 
@@ -62,12 +67,12 @@ DFInstallErrorDialog::DFInstallErrorDialog(QWidget *parent, const QStringList &e
 *************************************************************************/
 DFInstallErrorDialog::~DFInstallErrorDialog()
 {
-    qDebug() << __func__ << "start" << endl;
+    qDebug() << "DFInstallErrorDialog destructor start";
     emit m_signalManager->hideInstallErrorDialog();
     m_errorInstallFiles.clear();
     m_installErrorFontModelList.clear();
 //    m_NeedSelectFiles.clear();
-    qDebug() << __func__ << "end" << endl;
+    qDebug() << "DFInstallErrorDialog destructor end";
 }
 
 /*************************************************************************
@@ -96,7 +101,7 @@ void DFInstallErrorDialog::initData()
             itemModel.strFontFileName = fileInfo.fileName();
             itemModel.strFontFilePath = fileInfo.filePath();
             itemModel.strFontInstallStatus = DApplication::translate("DFInstallErrorDialog", "Broken file");
-
+            qWarning() << "Found broken font file:" << fileInfo.fileName();
             m_installErrorFontModelList.push_back(itemModel);
         } else if (fontInfo.isInstalled && !m_parent->isSystemFont(fontInfo)) {
             QFileInfo fileInfo(it);
@@ -118,6 +123,7 @@ void DFInstallErrorDialog::initData()
             itemModel.strFontFileName = fileInfo.fileName();
             itemModel.strFontFilePath = fileInfo.filePath();
             itemModel.strFontInstallStatus = DApplication::translate("DFInstallErrorDialog", "System Font");
+            qInfo() << "Found system font:" << fileInfo.fileName();
             m_installErrorFontModelList.push_back(itemModel);
         } else {
 //            qDebug() << "verifyFontFiles->" << it << " :new file";
@@ -137,7 +143,11 @@ void DFInstallErrorDialog::initData()
 void DFInstallErrorDialog::initUI()
 {
     setContentsMargins(0, 0, 0, 0);
+#if QT_VERSION_MAJOR > 5
+    setIcon(Utils::renderSVG("://exception-logo.svg", QSize(32, 32)));
+#else
     setIconPixmap(Utils::renderSVG("://exception-logo.svg", QSize(32, 32)));
+#endif
     setWindowTitle(DApplication::translate("ExceptionWindow", "Font Verification"));
 
     this->setFixedSize(448, 302);
@@ -155,11 +165,15 @@ void DFInstallErrorDialog::initUI()
     DVerticalLine *verticalSplit = new DVerticalLine;
     verticalSplit->setFixedWidth(1);
     verticalSplit->setFixedHeight(28);
+#if QT_VERSION_MAJOR > 5
+    DPalette pa = verticalSplit->palette();
+#else
     DPalette pa = DApplicationHelper::instance()->palette(verticalSplit);
+#endif
     QBrush splitBrush = pa.brush(DPalette::ItemBackground);
-    pa.setBrush(DPalette::Background, splitBrush);
+    pa.setBrush(DPalette::Window, splitBrush);
     verticalSplit->setPalette(pa);
-    verticalSplit->setBackgroundRole(QPalette::Background);
+    verticalSplit->setBackgroundRole(QPalette::Window);
     verticalSplit->setAutoFillBackground(true);
 
     m_installErrorListView = new DFInstallErrorListView(m_installErrorFontModelList, this);
@@ -358,7 +372,7 @@ void DFInstallErrorDialog::onListItemsClicked(const QModelIndexList &indexList)
         qvariant_cast<DFInstallErrorItemModel>(m_installErrorListView->getErrorListSourceModel()->data(firstIndex));
 
     for (auto &it : indexList) {
-        qDebug() << it.row() << "++++++++++++++++++++++++++++++" << endl;
+        qDebug() << it.row() << "++++++++++++++++++++++++++++++" << Qt::endl;
         DFInstallErrorItemModel itemModel2 =
             qvariant_cast<DFInstallErrorItemModel>(m_installErrorListView->getErrorListSourceModel()->data(it));
         if (itemModel2.bIsNormalUserFont) {
@@ -387,7 +401,7 @@ void DFInstallErrorDialog::addData(QStringList &errorFileList, QStringList &half
 
     for (auto &it : errorFileList) {
         fontInfo = fontInfoManager->getFontInfo(it);
-        qDebug() << "getfontinfo success!!!!!!!!!!1" << endl;
+        qDebug() << "getfontinfo success!!!!!!!!!!1" << Qt::endl;
         DFInstallErrorItemModel itemModel;
         if (fontInfo.isError) {
             QFileInfo fileInfo(it);
@@ -466,6 +480,7 @@ void DFInstallErrorDialog::onControlButtonClicked(int btnIndex)
 {
     if (0 == btnIndex) {
         //退出安装
+        qInfo() << "User canceled font installation";
         this->close();
     } else {
         //继续安装
@@ -479,6 +494,8 @@ void DFInstallErrorDialog::onControlButtonClicked(int btnIndex)
         }
 
         emit onContinueInstall(continueInstallFontFileList);
+        qInfo() << "User continued installation with" << continueInstallFontFileList.size()
+               << "selected fonts";
         this->reject();
     }
 }
@@ -489,10 +506,18 @@ void DFInstallErrorDialog::slotSizeModeChanged(DGuiApplicationHelper::SizeMode s
     Utils::clearImgCache();
     if (sizeMode == DGuiApplicationHelper::SizeMode::CompactMode) {
         this->setFixedSize(448, 259);
+#if QT_VERSION_MAJOR > 5
+        setIcon(Utils::renderSVG("://exception-logo.svg", QSize(25, 25)));
+#else
         setIconPixmap(Utils::renderSVG("://exception-logo.svg", QSize(25, 25)));
+#endif
     } else {
         this->setFixedSize(448, 302);
+#if QT_VERSION_MAJOR > 5
+        setIcon(Utils::renderSVG("://exception-logo.svg", QSize(32, 32)));
+#else
         setIconPixmap(Utils::renderSVG("://exception-logo.svg", QSize(32, 32)));
+#endif
     }
 }
 #endif
