@@ -32,6 +32,7 @@ dfontinfoscrollarea::dfontinfoscrollarea(DFontPreviewItemData *pData,  DWidget *
     : DFrame(parent)
     , m_fontInfo(pData)
 {
+    qDebug() << "Font info scroll area created for font:" << pData->fontInfo.familyName;
     installEventFilter(this);
 
     setFrameShape(QFrame::NoFrame);
@@ -258,18 +259,30 @@ QString dfontinfoscrollarea::elideText(QString &titleName) const
     int curWidth = 0;
 
     for (auto str : titleName) {
+#if QT_VERSION_MAJOR > 5
+        if (str == "\t") {
+            curWidth  += fontMetric.boundingRect("a").width();
+        } else {
+            curWidth  += fontMetric.boundingRect(str).width();
+        }
+#else
         if (str == "\t") {
             curWidth  += fontMetric.width("a");
         } else {
             curWidth  += fontMetric.width(str);
         }
+#endif
         m_curTitle += str;
         if (curWidth > TITLE_VISIBLE_WIDTH) {
             if (m_curTitle == titleName) {
                 finalTitle = titleName;
                 break;
             } else {
+#if QT_VERSION_MAJOR > 5
+                if (fontMetric.boundingRect("...").width() > IS_NEED_ELLIPSIS) {
+#else
                 if (fontMetric.width("...") > IS_NEED_ELLIPSIS) {
+#endif
                     finalTitle = m_curTitle;
                 } else {
                     finalTitle =   m_curTitle.append("...");
@@ -299,13 +312,21 @@ QString dfontinfoscrollarea::elideText(const QString &text, const QFont &font, i
 {
     QFontMetrics fm(font);
     QString strText = text;
+#if QT_VERSION_MAJOR > 5
+    int n_TextSize = fm.boundingRect(strText).width();
+#else
     int n_TextSize = fm.width(strText);
+#endif
     int count  = 0;
     if (n_TextSize > nLabelSize) {
         int n_position = 0;
         long n_curSumWidth = 0;
         for (int i = 0; i < strText.size(); i++) {
+#if QT_VERSION_MAJOR > 5
+            n_curSumWidth += fm.boundingRect(strText.at(i)).width();
+#else
             n_curSumWidth += fm.width(strText.at(i));
+#endif
             if (n_curSumWidth > nLabelSize * (count + 1)) {
                 n_position = i;
                 strText.insert(n_position, "\n");
@@ -326,6 +347,7 @@ QString dfontinfoscrollarea::elideText(const QString &text, const QFont &font, i
 *************************************************************************/
 void dfontinfoscrollarea::updateText()
 {
+    qDebug() << "Updating font info text display";
     for (auto pTltle : pTitleMap) {
         if (!pTltle.first) {
             continue;
@@ -354,6 +376,7 @@ void dfontinfoscrollarea::updateText()
 *************************************************************************/
 void dfontinfoscrollarea::autoHeight()
 {
+    qDebug() << "Adjusting scroll area height";
     int totalHeight = 0;
     for (auto plabeliter : pLabelMap) {
         if (!plabeliter.first) {
