@@ -1,31 +1,40 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="lt">
 <context>
     <name>Category</name>
     <message>
+        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="362"/>
         <source>All Fonts</source>
         <translation>Visi valdžios</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="363"/>
         <source>System</source>
         <translation>Sistemos</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="364"/>
         <source>User</source>
         <translation>Vartotojo</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="365"/>
         <source>Favorites</source>
         <translation>Mėgytos</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="366"/>
         <source>Active</source>
         <translation>Aktyvus</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="367"/>
         <source>Chinese</source>
         <translation>Kinų</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="368"/>
         <source>Monospaced</source>
         <translation>Raktų</translation>
     </message>
@@ -33,6 +42,7 @@
 <context>
     <name>DFDeleteDialog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="139"/>
         <source>Cancel</source>
         <comment>button</comment>
         <translation>Atšaukti</translation>
@@ -41,10 +51,12 @@
 <context>
     <name>DFDeleteTTCDialog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="550"/>
         <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
         <translation>%1 yra šriftų šeima, jei tęsytumėte, jų visi šriftai bus ištrinti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="544"/>
         <source>Delete</source>
         <comment>button</comment>
         <translation>Ištrinti</translation>
@@ -53,19 +65,23 @@
 <context>
     <name>DFDisableTTCDialog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="563"/>
         <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
         <translation>%1 yra šriftų šeima, jei tęsytumėte, jų visi šriftai bus įjungti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="565"/>
         <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
         <translation>%1 yra šriftų šeima, jei tęsytumėte, jų visi šriftai bus išjungti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="576"/>
         <source>Enable</source>
         <comment>button</comment>
         <translation>Įjungti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="578"/>
         <source>Disable</source>
         <comment>button</comment>
         <translation>Išjungti</translation>
@@ -74,10 +90,12 @@
 <context>
     <name>DFHandleTTCDialog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="467"/>
         <source>Apply to all selected font families</source>
-        <translation>Tol.getElementsByName(&apos;translation&apos;)ei į kiekvieną pasirinktą šriftų šeimą</translation>
+        <translation>Tol.getElementsByName('translation')ei į kiekvieną pasirinktą šriftų šeimą</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="480"/>
         <source>Cancel</source>
         <translation>Atšaukti</translation>
     </message>
@@ -85,14 +103,17 @@
 <context>
     <name>DFInstallErrorDialog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="103"/>
         <source>Broken file</source>
         <translation>Rozinusis failas</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="114"/>
         <source>Same version installed</source>
         <translation>Įdiegta ta pati versija</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="125"/>
         <source>System Font</source>
         <translation>Sistemos šriftas</translation>
     </message>
@@ -100,66 +121,82 @@
 <context>
     <name>DFontMgrMainWindow</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="371"/>
         <source>Ctrl+Shift+/</source>
         <translation>Ctrl+Shift+/</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="384"/>
         <source>PgUp</source>
         <translation>PgUp</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="403"/>
         <source>PgDown</source>
         <translation>PgDown</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="423"/>
         <source>Ctrl+Alt+F</source>
         <translation>Ctrl+Alt+F</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="441"/>
         <source>Ctrl+F</source>
         <translation>Ctrl+F</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="521"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="326"/>
         <source>Ctrl+=</source>
         <translation>Ctrl+=</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="342"/>
         <source>Ctrl+-</source>
         <translation>Ctrl+-</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="358"/>
         <source>Ctrl+0</source>
         <translation>Ctrl+0</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1654"/>
         <source>%1 font installed</source>
         <translation>%1 šriftas įdiegtas</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1656"/>
         <source>%1 fonts installed</source>
         <translation>%1 šriftai įdiegti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="474"/>
         <source>Alt+M</source>
         <translation>Alt+M</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="562"/>
         <source>CTRL+I</source>
         <translation>CTRL+I</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1661"/>
         <source>Failed to install %1 font. There is not enough disk space.</source>
         <translation>Nepavyko įdiegti %1 šriftą. Nėra pakankamios disko vietos.</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1663"/>
         <source>Failed to install %1 fonts. There is not enough disk space.</source>
         <translation>Nepavyko įdiegti %1 šriftų. Nėra pakankamios disko vietos.</translation>
     </message>
     <message>
+        <location filename="../libdeepin-font-manager/dcopyfilesmanager.h" line="12"/>
         <source>Fonts</source>
         <translation>Šriftai</translation>
     </message>
@@ -167,6 +204,7 @@
 <context>
     <name>DFontWidget</name>
     <message>
+        <location filename="../libdeepin-font-manager/dfontwidget.cpp" line="127"/>
         <source>Broken file</source>
         <translation>Klaidingas failas</translation>
     </message>
@@ -174,30 +212,37 @@
 <context>
     <name>DeleteConfirmDailog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="229"/>
         <source>This font will not be available to applications</source>
         <translation>Šis šriftas nebus ypač prieinamas programoms</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="231"/>
         <source>These fonts will not be available to applications</source>
         <translation>Šie šriftai nebus ypač prieinami programoms</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="234"/>
         <source>The other %1 system fonts cannot be deleted</source>
         <translation>Kiti %1 sistema šriftai negali būti ištrinti</translation>
     </message>
     <message>
-        <source>The font &quot;%1&quot; in use cannot be deleted</source>
-        <translation>Naudojama šriftas &quot;%1&quot; negali būti ištrintas</translation>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="237"/>
+        <source>The font "%1" in use cannot be deleted</source>
+        <translation>Naudojama šriftas "%1" negali būti ištrintas</translation>
     </message>
     <message>
-        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
-        <translation>Kiti %1 sistema šriftai ir naudojamas šriftas &quot;%2&quot; negali būti ištrinti</translation>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="240"/>
+        <source>The other %1 system fonts and the font "%2" in use cannot be deleted</source>
+        <translation>Kiti %1 sistema šriftai ir naudojamas šriftas "%2" negali būti ištrinti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="204"/>
         <source>Are you sure you want to delete %1 font(s)?</source>
         <translation>Ar tikrai norite ištrinti %1 šriftą(us)?</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="140"/>
         <source>Delete</source>
         <comment>button</comment>
         <translation>Ištrinti</translation>
@@ -206,6 +251,7 @@
 <context>
     <name>Dfuninstalldialog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfontspinnerwidget.cpp" line="74"/>
         <source>Deleting fonts, please wait...</source>
         <translation>Šriftai ištrinami, palaukite...</translation>
     </message>
@@ -213,18 +259,22 @@
 <context>
     <name>ExceptionWindow</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="151"/>
         <source>Font Verification</source>
         <translation>Šriftų patikrinimas</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="252"/>
         <source>No fonts to be installed</source>
         <translation>Nėra įdiegiamo šriftų</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="186"/>
         <source>Exit</source>
         <translation>Išeiti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="187"/>
         <source>Continue</source>
         <translation>Tęsti</translation>
     </message>
@@ -232,53 +282,65 @@
 <context>
     <name>Font</name>
     <message>
-        <source>Don&apos;t let your dreams be dreams</source>
+        <location filename="../libdeepin-font-manager/dfontpreviewitemdef.h" line="15"/>
+        <source>Don't let your dreams be dreams</source>
         <translation>Nepaslėpęs savo mėgstamųjų</translation>
     </message>
 </context>
 <context>
     <name>FontDetailDailog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="131"/>
         <source>Basic info</source>
         <translation>Pagrindinė informacija</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="60"/>
         <source>Style</source>
         <translation>Stylis</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="62"/>
         <source>Type</source>
         <translation>Tipas</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="66"/>
         <source>Version</source>
         <translation>Versija</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="72"/>
         <source>Description</source>
         <translation>Aprašymas</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="73"/>
         <source>Unknown</source>
-        <translation type="unfinished"/>
+        <translation>Nežinoma</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="78"/>
         <source>Full name</source>
         <translation>Pilnas pavadinimas</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="79"/>
         <source>Ps name</source>
         <translation>Ps pavadinimas</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="80"/>
         <source>Trademark</source>
         <translation>Marka</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="123"/>
         <source>Copyright</source>
         <translation>Teisės įrašai</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="124"/>
         <source>License Description</source>
         <translation>Licencavimo aprašymas</translation>
     </message>
@@ -286,30 +348,37 @@
 <context>
     <name>Main</name>
     <message>
+        <location filename="../deepin-font-manager/main.cpp" line="60"/>
         <source>Font Manager</source>
         <translation>Tipografinių ženklų tvarkytojas</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/main.cpp" line="61"/>
         <source>Font Manager helps users install and manage fonts.</source>
         <translation>Tipografinių ženklų tvarkytojas padeda vartotojams įdiegti ir tvarkyti tipografinių ženklų.</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontspinnerwidget.cpp" line="37"/>
         <source>Loading fonts, please wait...</source>
         <translation>Rodyti tipografinius ženklus, lūkesčiau palaukite...</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2093"/>
         <source>The font exported to your desktop</source>
         <translation>Tipografinis ženklas išvežtas į jūsų stebėjimo ekraną</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2095"/>
         <source>%1 fonts exported to your desktop</source>
         <translation>%1 tipografiniai ženklai išvežti į jūsų stebėjimo ekraną</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2099"/>
         <source>Failed to export 1 font. There is not enough disk space.</source>
         <translation>Nepavyko išvežti 1 tipografinio ženklų. Nėra irogų vietos.</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2102"/>
         <source>Failed to export %1 fonts. There is not enough disk space.</source>
         <translation>Nepavyko išvežti %1 tipografinių ženklų. Nėra irogų vietos.</translation>
     </message>
@@ -317,38 +386,47 @@
 <context>
     <name>Menu</name>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="63"/>
         <source>Add font</source>
         <translation>Pridėti tipografinį ženklą</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="71"/>
         <source>Enable</source>
         <translation>Įjungti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="297"/>
         <source>Disable</source>
         <translation>Išjungti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="73"/>
         <source>Delete</source>
         <translation>Ilipti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="77"/>
         <source>Favorite</source>
         <translation>Nagrinėti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="278"/>
         <source>Unfavorite</source>
         <translation>Ištraukti iš nagrinėjimo sąrašo</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="80"/>
         <source>Details</source>
         <translation>Detalės</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="83"/>
         <source>Display in file manager</source>
         <translation>Rodyti failų tvarkytojo sąraše</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="75"/>
         <source>Export</source>
         <translation>Eksportuoti</translation>
     </message>
@@ -356,22 +434,27 @@
 <context>
     <name>MessageManager</name>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1875"/>
         <source>deactivated</source>
         <translation>išjungta</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1877"/>
         <source>The fonts have been deactivated</source>
         <translation>Šriftai buvo išjungti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1867"/>
         <source>%1 is in use, so you cannot disable it</source>
         <translation>%1 yra naudojamas, todėl jį negalite išjungti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1869"/>
         <source>You cannot disable system fonts and the fonts in use</source>
         <translation>Ne galite išjungti sisteminius šriftus ir naudojamos šriftus</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1871"/>
         <source>You cannot disable system fonts</source>
         <translation>Ne galite išjungti sisteminius šriftus</translation>
     </message>
@@ -379,10 +462,12 @@
 <context>
     <name>NormalInstallWindow</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallnormalwindow.cpp" line="130"/>
         <source>Install Font</source>
         <translation>Installerinti šriftą</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallnormalwindow.cpp" line="143"/>
         <source>Verifying...</source>
         <translation>Patikrinama...</translation>
     </message>
@@ -390,22 +475,27 @@
 <context>
     <name>QuickInstallWindow</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="77"/>
         <source>Unknown</source>
-        <translation type="unfinished"/>
+        <translation>Nežinoma</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="206"/>
         <source>Broken file</source>
         <translation>Klaidingas failas</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="227"/>
         <source>Installed</source>
-        <translation type="unfinished"/>
+        <translation>Įdiegta</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="232"/>
         <source>Not Installed</source>
         <translation>Neįdiegtas</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="127"/>
         <source>Install Font</source>
         <translation>Installerinti šriftą</translation>
     </message>
@@ -413,14 +503,17 @@
 <context>
     <name>SearchBar</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="653"/>
         <source>Search</source>
         <translation>Ieškoti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="838"/>
         <source>No search results</source>
         <translation>Nėra ieškomo duomenų</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="860"/>
         <source>No fonts</source>
         <translation>Nėra šriftų</translation>
     </message>
@@ -428,38 +521,47 @@
 <context>
     <name>Shortcut</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2275"/>
         <source>Help</source>
         <translation>Pagalba</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2280"/>
         <source>Display shortcuts</source>
         <translation>Rodyti spartus mygtukus</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2281"/>
         <source>Page up</source>
         <translation>Puslapis atgal</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2282"/>
         <source>Page down</source>
         <translation>Puslapis priekai</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2285"/>
         <source>Delete</source>
         <translation>Ištrinti</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2286"/>
         <source>Add font</source>
         <translation>Pridėti šriftą</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2287"/>
         <source>Favorite</source>
         <translation>Sukurti mėgautinį</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2288"/>
         <source>Unfavorite</source>
         <translation>Pašalinti mėgautinį</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2289"/>
         <source>Font info</source>
         <translation>Šriftas informacija</translation>
     </message>
@@ -467,8 +569,9 @@
 <context>
     <name>StateBar</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="901"/>
         <source>Input preview text</source>
         <translation>Įvesti preview tekstą</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
